# edufin

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)
[![PyPI version](https://badge.fury.io/py/edufin.svg)](https://badge.fury.io/py/edufin)
[![Build Status](https://travis-ci.org/msalaztor/edufin.svg?branch=master)](https://travis-ci.org/msalaztor/edufin)
[![Documentation Status](https://readthedocs.org/projects/edufin/badge/?version=latest)](https://edufin.readthedocs.io/en/latest/?badge=latest)

Libreria para realizar una evaluación financiera de un proyecto. 

## Funcionalidades

- Calculo de Flujos
- Calculo de TIR
- Calculo de VAN
- Calculo de Indice de Recuperación

## Installation

```bash
pip install edufin

import edufin

